@@ -10,6 +10,9 @@ def is_django_unittest(item):
     except ImportError:
         from django.test import TestCase
 
+    if not hasattr(item, 'obj'):
+            return False
+
     if sys.version_info < (3, 0):
         return (hasattr(item.obj, 'im_class') and
                 issubclass(item.obj.im_class, TestCase))
